@@ -140,7 +140,7 @@ class Config(Base):
 
     __tablename__ = 'config'
 
-    config_id = Column(VARCHAR(20), primary_key=True)
+    config_id = Column(VARCHAR(50), primary_key=True)
     config = Column(JSONB)
 
     def __repr__(self):
@@ -667,24 +667,25 @@ if __name__ == '__main__':
     if not init(cfg):
         logger.warning(f"not init()")
     else:
-        new_cronjob_task = {'schedule': '*/1 * * * *',
-                            'module': 'Modules.TestTasks',
-                            'func': 'raise_exception',  # raise_exception, sleep_false, sleep
-                            'params': {"counter": 4},
-                            'project': 'project_2',
-                            'max_retry_count': 2,
-                            'enabled': True}
-        # new_cronjob_task = CronjobTask(**new_cronjob_task)
-        # from Modules import TestTasks
-        # new_cronjob_task = add_cronjob_task(new_cronjob_task, TestTasks.raise_exception)
-        new_cronjob_task = add_cronjob_task(new_cronjob_task)
-        print(f'new_cronjob_task: {new_cronjob_task}')
+        # new_cronjob_task = {'schedule': '*/1 * * * *',
+        #                     'module': 'Modules.TestTasks',
+        #                     'func': 'return_none',
+        #                     # test_mem, raise_exception, sleep_false, sleep, not_return, return_none
+        #                     'params': {"counter": 10},
+        #                     'project': 'project_2',
+        #                     'max_retry_count': 2,
+        #                     'enabled': True}
+        # # new_cronjob_task = CronjobTask(**new_cronjob_task)
+        # # from Modules import TestTasks
+        # # new_cronjob_task = add_cronjob_task(new_cronjob_task, TestTasks.raise_exception)
+        # new_cronjob_task = add_cronjob_task(new_cronjob_task)
+        # print(f'new_cronjob_task: {new_cronjob_task}')
 
         import datetime
         new_task = {'module': 'Modules.TestTasks',
-                    'func': 'raise_exception',
+                    'func': 'return_none',
                     'params': {"counter": 4},
-                    'max_retry_count': 20,
+                    'max_retry_count': 2,
                     'scheduled_time': datetime.datetime.now(),
                     'priority': 1}
         new_task = add_task(new_task)
